==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1TopologySelectorTermFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1TopologySelectorTermFluent<A extends V1TopologySelectorTermFluent<A>> extends Fluent<A>{


    public A addToMatchLabelExpressions(int index,V1TopologySelectorLabelRequirement item);
    public A setToMatchLabelExpressions(int index,V1TopologySelectorLabelRequirement item);
    public A addToMatchLabelExpressions(V1TopologySelectorLabelRequirement... items);
    public A addAllToMatchLabelExpressions(Collection<V1TopologySelectorLabelRequirement> items);
    public A removeFromMatchLabelExpressions(V1TopologySelectorLabelRequirement... items);
    public A removeAllFromMatchLabelExpressions(Collection<V1TopologySelectorLabelRequirement> items);
    
/**
 * This method has been deprecated, please use method buildMatchLabelExpressions instead.
 * @return The buildable object.
 */
@Deprecated public List<V1TopologySelectorLabelRequirement> getMatchLabelExpressions();
    public List<V1TopologySelectorLabelRequirement> buildMatchLabelExpressions();
    public V1TopologySelectorLabelRequirement buildMatchLabelExpression(int index);
    public V1TopologySelectorLabelRequirement buildFirstMatchLabelExpression();
    public V1TopologySelectorLabelRequirement buildLastMatchLabelExpression();
    public V1TopologySelectorLabelRequirement buildMatchingMatchLabelExpression(io.kubernetes.client.fluent.Predicate<V1TopologySelectorLabelRequirementBuilder> predicate);
    public A withMatchLabelExpressions(List<V1TopologySelectorLabelRequirement> matchLabelExpressions);
    public A withMatchLabelExpressions(V1TopologySelectorLabelRequirement... matchLabelExpressions);
    public Boolean hasMatchLabelExpressions();
    public V1TopologySelectorTermFluent.MatchLabelExpressionsNested<A> addNewMatchLabelExpression();
    public V1TopologySelectorTermFluent.MatchLabelExpressionsNested<A> addNewMatchLabelExpressionLike(V1TopologySelectorLabelRequirement item);
    public V1TopologySelectorTermFluent.MatchLabelExpressionsNested<A> setNewMatchLabelExpressionLike(int index,V1TopologySelectorLabelRequirement item);
    public V1TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editMatchLabelExpression(int index);
    public V1TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editFirstMatchLabelExpression();
    public V1TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editLastMatchLabelExpression();
    public V1TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editMatchingMatchLabelExpression(io.kubernetes.client.fluent.Predicate<V1TopologySelectorLabelRequirementBuilder> predicate);

    public interface MatchLabelExpressionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1TopologySelectorLabelRequirementFluent<V1TopologySelectorTermFluent.MatchLabelExpressionsNested<N>>{

        
    public N and();    public N endMatchLabelExpression();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1TopologySelectorTermFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1TopologySelectorTermFluent<A extends V1TopologySelectorTermFluent<A>> extends Fluent<A>{


    public A addToMatchLabelExpressions(int index,V1TopologySelectorLabelRequirement item);
    public A setToMatchLabelExpressions(int index,V1TopologySelectorLabelRequirement item);
    public A addToMatchLabelExpressions(V1TopologySelectorLabelRequirement... items);
    public A addAllToMatchLabelExpressions(Collection<V1TopologySelectorLabelRequirement> items);
    public A removeFromMatchLabelExpressions(V1TopologySelectorLabelRequirement... items);
    public A removeAllFromMatchLabelExpressions(Collection<V1TopologySelectorLabelRequirement> items);
    
/**
 * This method has been deprecated, please use method buildMatchLabelExpressions instead.
 * @return The buildable object.
 */
@Deprecated public List<V1TopologySelectorLabelRequirement> getMatchLabelExpressions();
    public List<V1TopologySelectorLabelRequirement> buildMatchLabelExpressions();
    public V1TopologySelectorLabelRequirement buildMatchLabelExpression(int index);
    public V1TopologySelectorLabelRequirement buildFirstMatchLabelExpression();
    public V1TopologySelectorLabelRequirement buildLastMatchLabelExpression();
    public V1TopologySelectorLabelRequirement buildMatchingMatchLabelExpression(io.kubernetes.client.fluent.Predicate<V1TopologySelectorLabelRequirementBuilder> predicate);
    public Boolean hasMatchingMatchLabelExpression(io.kubernetes.client.fluent.Predicate<V1TopologySelectorLabelRequirementBuilder> predicate);
    public A withMatchLabelExpressions(List<V1TopologySelectorLabelRequirement> matchLabelExpressions);
    public A withMatchLabelExpressions(V1TopologySelectorLabelRequirement... matchLabelExpressions);
    public Boolean hasMatchLabelExpressions();
    public V1TopologySelectorTermFluent.MatchLabelExpressionsNested<A> addNewMatchLabelExpression();
    public V1TopologySelectorTermFluent.MatchLabelExpressionsNested<A> addNewMatchLabelExpressionLike(V1TopologySelectorLabelRequirement item);
    public V1TopologySelectorTermFluent.MatchLabelExpressionsNested<A> setNewMatchLabelExpressionLike(int index,V1TopologySelectorLabelRequirement item);
    public V1TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editMatchLabelExpression(int index);
    public V1TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editFirstMatchLabelExpression();
    public V1TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editLastMatchLabelExpression();
    public V1TopologySelectorTermFluent.MatchLabelExpressionsNested<A> editMatchingMatchLabelExpression(io.kubernetes.client.fluent.Predicate<V1TopologySelectorLabelRequirementBuilder> predicate);

    public interface MatchLabelExpressionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1TopologySelectorLabelRequirementFluent<V1TopologySelectorTermFluent.MatchLabelExpressionsNested<N>>{

        
    public N and();    public N endMatchLabelExpression();
}


}
